@@ -1,6 +1,6 @@
 /* gda-data-model-iter.h
  *
- * Copyright (C) 2005 ( 2006 Vivien Malerba
+ * Copyright (C) 2005 - 2008 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -23,7 +23,7 @@
 #define __GDA_DATA_MODEL_ITER_H_
 
 #include "gda-decl.h"
-#include "gda-parameter-list.h"
+#include "gda-set.h"
 
 G_BEGIN_DECLS
 
@@ -39,41 +39,42 @@ extern GQuark gda_data_model_iter_error_quark (void);
 
 typedef enum
 {
-	GDA_DATA_MODEL_ITER_WHAT_ERROR,
+	GDA_DATA_MODEL_ITER_COLUMN_OUT_OF_RANGE_ERROR
 } GdaDataModelIterError;
 
 
 /* struct for the object's data */
 struct _GdaDataModelIter
 {
-	GdaParameterList           object;
+	GdaSet                     object;
 	GdaDataModelIterPrivate   *priv;
 };
 
 /* struct for the object's class */
 struct _GdaDataModelIterClass
 {
-	GdaParameterListClass      parent_class;
+	GdaSetClass                parent_class;
 
-	gboolean                (* row_to_change)    (GdaDataModelIter *iter, gint row);
 	void                    (* row_changed)      (GdaDataModelIter *iter, gint row);
 	void                    (* end_of_data)      (GdaDataModelIter *iter);
 };
 
-GType             gda_data_model_iter_get_type             (void);
-GdaDataModelIter *gda_data_model_iter_new                  (GdaDataModel *model);
+GType             gda_data_model_iter_get_type             (void) G_GNUC_CONST;
 
-gboolean          gda_data_model_iter_set_at_row           (GdaDataModelIter *iter, gint row);
+const GValue     *gda_data_model_iter_get_value_at         (GdaDataModelIter *iter, gint col);
+const GValue     *gda_data_model_iter_get_value_for_field  (GdaDataModelIter *iter, const gchar *field_name);
+gboolean          gda_data_model_iter_set_value_at         (GdaDataModelIter *iter, gint col, 
+							    const GValue *value, GError **error);
+
+gboolean          gda_data_model_iter_move_at_row          (GdaDataModelIter *iter, gint row);
 gboolean          gda_data_model_iter_move_next            (GdaDataModelIter *iter);
 gboolean          gda_data_model_iter_move_prev            (GdaDataModelIter *iter);
 gint              gda_data_model_iter_get_row              (GdaDataModelIter *iter);
 
-gboolean          gda_data_model_iter_can_be_moved       (GdaDataModelIter *iter);
 void              gda_data_model_iter_invalidate_contents  (GdaDataModelIter *iter);
 gboolean          gda_data_model_iter_is_valid             (GdaDataModelIter *iter);
 
-gint              gda_data_model_iter_get_column_for_param (GdaDataModelIter *iter, GdaParameter *param);
-GdaParameter     *gda_data_model_iter_get_param_for_column (GdaDataModelIter *iter, gint col);
+GdaHolder        *gda_data_model_iter_get_holder_for_field (GdaDataModelIter *iter, gint col);
 
 G_END_DECLS
 
