@@ -157,8 +157,8 @@ do_notify_changes (GdaDataModel *model)
 	return notify_changes;
 }
 
-/**
- * gda_data_model_signal_emit_changed
+/*
+ * _gda_data_model_signal_emit_changed
  * @model: a #GdaDataModel object.
  *
  * Notifies listeners of the given data model object of changes
@@ -167,8 +167,8 @@ do_notify_changes (GdaDataModel *model)
  * class, thus being notified of any new data being appended
  * or removed from the data model.
  */
-void
-gda_data_model_signal_emit_changed (GdaDataModel *model)
+static void
+_gda_data_model_signal_emit_changed (GdaDataModel *model)
 {
 	g_return_if_fail (GDA_IS_DATA_MODEL (model));
 	
@@ -212,7 +212,7 @@ gda_data_model_row_inserted (GdaDataModel *model, gint row)
 			       gda_data_model_signals[ROW_INSERTED],
 			       0, row);
 
-		gda_data_model_signal_emit_changed (model);
+		_gda_data_model_signal_emit_changed (model);
 	}
 }
 
@@ -236,7 +236,7 @@ gda_data_model_row_updated (GdaDataModel *model, gint row)
 			       gda_data_model_signals[ROW_UPDATED],
 			       0, row);
 
-		gda_data_model_signal_emit_changed (model);
+		_gda_data_model_signal_emit_changed (model);
 	}
 }
 
@@ -260,7 +260,7 @@ gda_data_model_row_removed (GdaDataModel *model, gint row)
 			       gda_data_model_signals[ROW_REMOVED],
 			       0, row);
 
-		gda_data_model_signal_emit_changed (model);
+		_gda_data_model_signal_emit_changed (model);
 	}
 }
 
@@ -278,7 +278,7 @@ gda_data_model_reset (GdaDataModel *model)
 	g_signal_emit (G_OBJECT (model),
 		       gda_data_model_signals[RESET], 0);
 
-	gda_data_model_signal_emit_changed (model);
+	_gda_data_model_signal_emit_changed (model);
 }
 
 /**
@@ -371,6 +371,7 @@ gda_data_model_get_n_columns (GdaDataModel *model)
 		return (GDA_DATA_MODEL_GET_CLASS (model)->i_get_n_columns) (model);
 	else {
 		/* method not supported */
+		g_warning ("%s() method not supported\n", __FUNCTION__);
 		return -1;
 	}
 }
@@ -399,6 +400,7 @@ gda_data_model_describe_column (GdaDataModel *model, gint col)
 		return (GDA_DATA_MODEL_GET_CLASS (model)->i_describe_column) (model, col);
 	else {
 		/* method not supported */
+		g_warning ("%s() method not supported\n", __FUNCTION__);
 		return NULL;
 	}
 }
@@ -693,6 +695,8 @@ gda_data_model_set_values (GdaDataModel *model, gint row, GList *values, GError
 		return (GDA_DATA_MODEL_GET_CLASS (model)->i_set_values) (model, row, values, error);
 	else {
 		/* method not supported */
+		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_FEATURE_NON_SUPPORTED_ERROR,
+			     _("Data model does not support setting values"));
 		return FALSE;
 	}
 }
@@ -745,6 +749,8 @@ gda_data_model_append_values (GdaDataModel *model, const GList *values, GError *
 		return (GDA_DATA_MODEL_GET_CLASS (model)->i_append_values) (model, values, error);
 	else {
 		/* method not supported */
+		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_FEATURE_NON_SUPPORTED_ERROR,
+			     _("Data model does not support row append"));
 		return -1;
 	}
 }
@@ -765,7 +771,7 @@ gda_data_model_append_row (GdaDataModel *model, GError **error)
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), FALSE);
 
 	if (! (gda_data_model_get_access_flags (model) & GDA_DATA_MODEL_ACCESS_INSERT)) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_ACCESS_ERROR,
 			     _("Model does not allow row insertion"));
 		return -1;
 	}
@@ -774,6 +780,8 @@ gda_data_model_append_row (GdaDataModel *model, GError **error)
 		return (GDA_DATA_MODEL_GET_CLASS (model)->i_append_row) (model, error);
 	else {
 		/* method not supported */
+		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_FEATURE_NON_SUPPORTED_ERROR,
+			     _("Data model does not support row append"));
 		return -1;
 	}
 }
@@ -795,7 +803,7 @@ gda_data_model_remove_row (GdaDataModel *model, gint row, GError **error)
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), FALSE);
 
 	if (! (gda_data_model_get_access_flags (model) & GDA_DATA_MODEL_ACCESS_DELETE)) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_ACCESS_ERROR,
 			     _("Model does not allow row deletion"));
 		return FALSE;
 	}
@@ -804,6 +812,8 @@ gda_data_model_remove_row (GdaDataModel *model, gint row, GError **error)
 		return (GDA_DATA_MODEL_GET_CLASS (model)->i_remove_row) (model, row, error);
 	else {
 		/* method not supported */
+		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_FEATURE_NON_SUPPORTED_ERROR,
+			     _("Data model does not support row removal"));
 		return FALSE;
 	}
 }
@@ -1096,7 +1106,7 @@ gda_data_model_export_to_file (GdaDataModel *model, GdaDataModelIOFormat format,
 	if (g_file_test (file, G_FILE_TEST_EXISTS)) {
 		if (! overwrite) {
 			g_free (body);
-			g_set_error (error, 0, 0,
+			g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_FILE_EXIST_ERROR,
 				     _("File '%s' already exists"), file);
 			return FALSE;
 		}
@@ -1325,9 +1335,11 @@ add_xml_row (GdaDataModel *model, xmlNodePtr xml_row, GError **error)
 		if (xmlNodeIsText (xml_field))
 			continue;
 
-		if (strcmp ((gchar*)xml_field->name, "gda_value") && strcmp ((gchar*)xml_field->name, "gda_array_value")) {
-			g_set_error (error, 0, 0, _("Expected tag <gda_value> or <gda_array_value>, "
-						    "got <%s>, ignoring"), (gchar*)xml_field->name);
+		if (strcmp ((gchar*)xml_field->name, "gda_value") && 
+		    strcmp ((gchar*)xml_field->name, "gda_array_value")) {
+			g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_XML_FORMAT_ERROR,
+				     _("Expected tag <gda_value> or <gda_array_value>, "
+				       "got <%s>, ignoring"), (gchar*)xml_field->name);
 			continue;
 		}
 		
@@ -1356,7 +1368,7 @@ add_xml_row (GdaDataModel *model, xmlNodePtr xml_row, GError **error)
 		gdatype = gda_column_get_g_type (column);
 		if ((gdatype == G_TYPE_INVALID) ||
 		    (gdatype == GDA_TYPE_NULL)) {
-			g_set_error (error, 0, 0,
+			g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_XML_FORMAT_ERROR,
 				     _("Cannot retrieve column data type (type is UNKNOWN or not specified)"));
 			retval = FALSE;
 			break;
@@ -1438,7 +1450,7 @@ gda_data_model_add_data_from_xml_node (GdaDataModel *model, xmlNodePtr node, GEr
 		node = node->next;
 
 	if (strcmp ((gchar*)node->name, "gda_array_data")) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_XML_FORMAT_ERROR,
 			     _("Expected tag <gda_array_data>, got <%s>"), node->name);
 		return FALSE;
 	}
@@ -1498,7 +1510,7 @@ gda_data_model_import_from_model (GdaDataModel *to, GdaDataModel *from,
 	/* obtain an iterator */
 	from_iter = gda_data_model_create_iter (from);
 	if (!from_iter) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_ACCESS_ERROR,
 			     _("Could not get an iterator for source data model"));
 		return FALSE;
 	}
@@ -1515,7 +1527,7 @@ gda_data_model_import_from_model (GdaDataModel *to, GdaDataModel *from,
 			col = GPOINTER_TO_INT (g_hash_table_lookup (cols_trans, GINT_TO_POINTER (i)));
 			if (col >= from_nb_cols) {
 				g_slist_free (copy_params);
-				g_set_error (error, 0, 0,
+				g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_COLUMN_OUT_OF_RANGE_ERROR,
 					     _("Inexistent column in source data model: %d"), col);
 				return FALSE;
 			}
@@ -1529,7 +1541,7 @@ gda_data_model_import_from_model (GdaDataModel *to, GdaDataModel *from,
 		column = gda_data_model_describe_column (to, i);
 		if (! gda_column_get_allow_null (column) && !param) {
 			g_slist_free (copy_params);
-			g_set_error (error, 0, 0,
+			g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_VALUE_TYPE_ERROR,
 				     _("Destination column %d can't be NULL but has no correspondence in the "
 				       "source data model"), i);
 			return FALSE;
@@ -1539,7 +1551,7 @@ gda_data_model_import_from_model (GdaDataModel *to, GdaDataModel *from,
 			    (gda_holder_get_g_type (param) != G_TYPE_INVALID) &&
 			    !g_value_type_transformable (gda_holder_get_g_type (param), 
 							 gda_column_get_g_type (column))) {
-				g_set_error (error, 0, 0,
+				g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_VALUE_TYPE_ERROR,
 					     _("Destination column %d has a gda type (%s) incompatible with "
 					       "source column %d type (%s)"), i,
 					     gda_g_type_to_string (gda_column_get_g_type (column)),
@@ -1636,7 +1648,7 @@ gda_data_model_import_from_model (GdaDataModel *to, GdaDataModel *from,
 						gchar *str;
 
 						str = gda_value_stringify (value);
-						g_set_error (error, 0, 0,
+						g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_VALUE_TYPE_ERROR,
 							     _("Can't transform '%s' from GDA type %s to GDA type %s"),
 							     str, 
 							     gda_g_type_to_string (G_VALUE_TYPE (value)),
