@@ -27,14 +27,15 @@
 
 #include <libgda/binreloc/gda-binreloc.h>
 #include <sql-parser/gda-sql-parser.h>
+#include <libgda/gda-error.h>
 
 /* global variables */
 xmlDtdPtr       gda_array_dtd = NULL;
 xmlDtdPtr       gda_paramlist_dtd = NULL;
 xmlDtdPtr       gda_server_op_dtd = NULL;
 
-gchar          *gda_numeric_locale = NULL;
-gchar          *gda_lang_locale = NULL;
+gchar          *gda_numeric_locale = "";
+gchar          *gda_lang_locale = "";
 
 /**
  * gda_init
@@ -102,6 +103,8 @@ gda_init (void)
 	g_assert (type);
 	type = GDA_TYPE_TIMESTAMP;
 	g_assert (type);
+	type = GDA_TYPE_ERROR;
+	g_assert (type);
 
 	/* acquire locale */
 	gda_numeric_locale = setlocale (LC_NUMERIC, NULL);
