@@ -44,7 +44,7 @@ typedef struct _GdaTransactionStatusEvent   GdaTransactionStatusEvent;
 typedef enum {
 	GDA_TRANSACTION_STATUS_EVENT_SAVEPOINT,
 	GDA_TRANSACTION_STATUS_EVENT_SQL,
-	GDA_TRANSACTION_STATUS_EVENT_SUB_TRANSACTION,
+	GDA_TRANSACTION_STATUS_EVENT_SUB_TRANSACTION
 } GdaTransactionStatusEventType;
 
 typedef enum {
@@ -80,7 +80,7 @@ struct _GdaTransactionStatusClass {
 	gpointer                 reserved[10];
 };
 
-GType                 gda_transaction_status_get_type (void);
+GType                 gda_transaction_status_get_type (void) G_GNUC_CONST;
 GdaTransactionStatus *gda_transaction_status_new      (const gchar *name);
 
 
