@@ -1,21 +1,21 @@
 /* gda-handler-type.c
  *
- * Copyright (C) 2005 - 2006 Vivien Malerba
+ * Copyright (C) 2005 - 2008 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include "gda-handler-type.h"
@@ -56,7 +56,8 @@ gda_handler_type_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
+		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
 		static const GTypeInfo info = {
 			sizeof (GdaHandlerTypeClass),
 			(GBaseInitFunc) NULL,
@@ -75,8 +76,12 @@ gda_handler_type_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GDA_TYPE_OBJECT, "GdaHandlerType", &info, 0);
-		g_type_add_interface_static (type, GDA_TYPE_DATA_HANDLER, &data_entry_info);
+		g_static_mutex_lock (&registering);
+		if (type == 0) {
+			type = g_type_register_static (G_TYPE_OBJECT, "GdaHandlerType", &info, 0);
+			g_type_add_interface_static (type, GDA_TYPE_DATA_HANDLER, &data_entry_info);
+		}
+		g_static_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -114,10 +119,10 @@ gda_handler_type_init (GdaHandlerType * hdl)
 	hdl->priv->detailled_descr = _("Gda type handler");
 	hdl->priv->nb_g_types = 1;
 	hdl->priv->valid_g_types = g_new0 (GType, 1);
-	hdl->priv->valid_g_types[0] = G_TYPE_ULONG;
+	hdl->priv->valid_g_types[0] = G_TYPE_GTYPE;
 
-	gda_object_set_name (GDA_OBJECT (hdl), _("InternalType"));
-	gda_object_set_description (GDA_OBJECT (hdl), _("Gda type representation"));
+	g_object_set_data (G_OBJECT (hdl), "descr", "InternalType");
+	g_object_set_data (G_OBJECT (hdl), "descr", _("Gda type representation"));
 }
 
 static void
@@ -131,8 +136,6 @@ gda_handler_type_dispose (GObject   * object)
 	hdl = GDA_HANDLER_TYPE (object);
 
 	if (hdl->priv) {
-		gda_object_destroy_check (GDA_OBJECT (object));
-
 		g_free (hdl->priv->valid_g_types);
 		hdl->priv->valid_g_types = NULL;
 
@@ -156,7 +159,7 @@ gda_handler_type_new (void)
 {
 	GObject *obj;
 
-	obj = g_object_new (GDA_TYPE_HANDLER_TYPE, "dict", NULL, NULL);
+	obj = g_object_new (GDA_TYPE_HANDLER_TYPE, NULL);
 
 	return (GdaDataHandler *) obj;
 }
@@ -172,9 +175,15 @@ gda_handler_type_get_sql_from_value (GdaDataHandler *iface, const GValue *value)
 	g_return_val_if_fail (hdl->priv, NULL);
 
 	if (value) {
-		const gchar *str;
-		str = g_type_to_string (g_value_get_ulong (value));
-		retval = g_strdup_printf ("'%s'", str);
+		GTypeQuery tq;
+		g_type_query (g_value_get_gtype (value), &tq);
+		if (tq.type != 0) {
+			const gchar *str;
+			str = gda_g_type_to_string (g_value_get_gtype (value));
+			retval = g_strdup_printf ("'%s'", str);
+		}
+		else
+			retval = g_strdup (NULL);	
 	}
 	else
 		retval = g_strdup (NULL);
@@ -192,8 +201,15 @@ gda_handler_type_get_str_from_value (GdaDataHandler *iface, const GValue *value)
 	hdl = GDA_HANDLER_TYPE (iface);
 	g_return_val_if_fail (hdl->priv, NULL);
 
-	if (value) 
-		retval = g_strdup (g_type_to_string (g_value_get_ulong (value)));
+	if (value) {
+		GTypeQuery tq;
+       
+		g_type_query (g_value_get_gtype (value), &tq);
+		if (tq.type != 0)
+			retval = g_strdup (gda_g_type_to_string (g_value_get_gtype (value)));
+		else
+			retval = g_strdup (NULL); /* FIXME: return NULL instead because of the error? */
+	}
 	else
 		retval = g_strdup (NULL);
 
@@ -216,10 +232,10 @@ gda_handler_type_get_value_from_sql (GdaDataHandler *iface, const gchar *sql, GT
 			gchar *str = g_strdup (sql);
 			GType type;
 			str[i-1] = 0;
-			type = g_type_from_string (str+1);
+			type = gda_g_type_from_string (str+1);
 			g_free (str);
-			value = g_value_init (g_new0 (GValue, 1), G_TYPE_ULONG);
-			g_value_set_ulong (value, type);
+			value = g_value_init (g_new0 (GValue, 1), G_TYPE_GTYPE);
+			g_value_set_gtype (value, type);
 		}
 	}
 	else
@@ -238,9 +254,9 @@ gda_handler_type_get_value_from_str (GdaDataHandler *iface, const gchar *str, GT
 	hdl = GDA_HANDLER_TYPE (iface);
 	g_return_val_if_fail (hdl->priv, NULL);
 
-	vtype = g_type_from_string (str);
-	value = g_value_init (g_new0 (GValue, 1), G_TYPE_ULONG);
-	g_value_set_ulong (value, vtype);
+	vtype = gda_g_type_from_string (str);
+	value = g_value_init (g_new0 (GValue, 1), G_TYPE_GTYPE);
+	g_value_set_gtype (value, vtype);
 
 	return value;
 }
@@ -301,5 +317,5 @@ gda_handler_type_get_descr (GdaDataHandler *iface)
 	hdl = GDA_HANDLER_TYPE (iface);
 	g_return_val_if_fail (hdl->priv, NULL);
 
-	return gda_object_get_description (GDA_OBJECT (hdl));
+	return g_object_get_data (G_OBJECT (hdl), "descr");
 }
