@@ -1,9 +1,8 @@
-/* GNOME DB Postgres Provider
- * Copyright (C) 2006 The GNOME Foundation
+/* GDA Postgres Provider
+ * Copyright (C) 2008 The GNOME Foundation
  *
  * AUTHORS:
- *         Vivien Malerba <malerba@gnome-db.org>
- *         Bas Driessen <bas.driessen@xobas.com>
+ *      TO_ADD: your name and email
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -21,9 +20,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "gda-postgres-ddl.h"
 #include <glib/gi18n-lib.h>
-#include <libgda/gda-data-handler.h>
+#include <libgda/libgda.h>
+#include "gda-postgres-ddl.h"
 
 gchar *
 gda_postgres_render_CREATE_DB (GdaServerProvider *provider, GdaConnection *cnc, 
@@ -37,7 +36,7 @@ gda_postgres_render_CREATE_DB (GdaServerProvider *provider, GdaConnection *cnc,
 
 	value = gda_server_operation_get_value_at (op, "/DB_DEF_P/DB_NAME");
 	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	g_string_append_printf (string, "\"%s\"", g_value_get_string (value));
 
 	value = gda_server_operation_get_value_at (op, "/DB_DEF_P/OWNER");
 	if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value)) {
@@ -56,7 +55,7 @@ gda_postgres_render_CREATE_DB (GdaServerProvider *provider, GdaConnection *cnc,
 		GdaDataHandler *dh;
 		gchar *str;
 		
-		dh = gda_server_provider_get_data_handler_gtype (provider, cnc, G_TYPE_STRING);
+		dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 		str = gda_data_handler_get_sql_from_value (dh, value);
 
 		g_string_append (string, " ENCODING ");
@@ -88,7 +87,7 @@ gda_postgres_render_DROP_DB (GdaServerProvider *provider, GdaConnection *cnc,
 
 	value = gda_server_operation_get_value_at (op, "/DB_DESC_P/DB_NAME");
 	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	g_string_append_printf (string, "\"%s\"", g_value_get_string (value));
 
 	sql = string->str;
 	g_string_free (string, FALSE);
@@ -96,7 +95,6 @@ gda_postgres_render_DROP_DB (GdaServerProvider *provider, GdaConnection *cnc,
 	return sql;	
 }
 
-
 gchar *
 gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc, 
 				  GdaServerOperation *op, GError **error)
@@ -155,8 +153,14 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 			g_string_append_c (string, '\"');
 			g_string_append_c (string, ' ');
 				
-			value = gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_TYPE/%d", i);
-			g_string_append (string, g_value_get_string (value));
+
+			value = gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_AUTOINC/%d", i);
+			if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
+				g_string_append (string, "serial");
+			else {
+				value = gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_TYPE/%d", i);
+				g_string_append (string, g_value_get_string (value));
+			}
 				
 			value = gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_SIZE/%d", i);
 			if (value && G_VALUE_HOLDS (value, G_TYPE_UINT)) {
@@ -239,7 +243,9 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 		while (list) {
 			if (list != pkfields)
 				g_string_append (string, ", ");
+			g_string_append_c (string, '\"');
 			g_string_append (string, g_value_get_string ((GValue*) list->data));
+			g_string_append_c (string, '\"');
 			list = list->next;
 		}
 		g_string_append_c (string, ')');
@@ -269,7 +275,11 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 						value = gda_server_operation_get_value_at (op, 
 											   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_FIELD/%d", i, j);
 						if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value))
+						{
+							g_string_append_c (string, '\"');
 							g_string_append (string, g_value_get_string (value));
+							g_string_append_c (string, '\"');
+						}
 						else {
 							allok = FALSE;
 							g_set_error (error, 0, 0, 
@@ -293,7 +303,11 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 					value = gda_server_operation_get_value_at (op, 
 										   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_REF_PK_FIELD/%d", i, j);
 					if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value))
+					{
+						g_string_append_c (string, '\"');
 						g_string_append (string, g_value_get_string (value));
+						g_string_append_c (string, '\"');
+					}
 					else {
 						allok = FALSE;
 						g_set_error (error, 0, 0, 
@@ -573,7 +587,9 @@ gda_postgres_render_CREATE_INDEX (GdaServerProvider *provider, GdaConnection *cn
 		if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value)) {
 			if (i != 0)
 				g_string_append (string, ", ");
+			g_string_append_c (string, '\"');
 			g_string_append (string, g_value_get_string (value));
+			g_string_append_c (string, '\"');
 		}
 	}
 
@@ -624,3 +640,105 @@ gda_postgres_render_DROP_INDEX   (GdaServerProvider *provider, GdaConnection *cn
 	return sql;
 }
 
+gchar *
+gda_postgres_render_CREATE_VIEW (GdaServerProvider *provider, GdaConnection *cnc, 
+				 GdaServerOperation *op, GError **error)
+{
+	GString *string;
+	const GValue *value;
+	gboolean allok = TRUE;
+	gchar *sql = NULL;
+
+	string = g_string_new ("CREATE ");
+
+	value = gda_server_operation_get_value_at (op, "/VIEW_DEF_P/VIEW_OR_REPLACE");
+	if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
+		g_string_append (string, "OR REPLACE ");
+
+	value = gda_server_operation_get_value_at (op, "/VIEW_DEF_P/VIEW_TEMP");
+	if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
+		g_string_append (string, "TEMP ");
+
+	g_string_append (string, "VIEW ");
+		
+	value = gda_server_operation_get_value_at (op, "/VIEW_DEF_P/VIEW_NAME");
+	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
+	g_string_append (string, g_value_get_string (value));
+	
+	if (allok) {
+		GdaServerOperationNode *node;
+
+		node = gda_server_operation_get_node_info (op, "/FIELDS_A");
+		if (node) {
+			gint i, nrows;
+			GString *cols = NULL;
+
+			nrows = gda_data_model_get_n_rows (node->model);
+			for (i = 0; i < nrows; i++) {
+				value = gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_NAME/%d", i);
+				if (!value || !G_VALUE_HOLDS (value, G_TYPE_STRING))
+					continue;
+				if (!cols)
+					cols = g_string_new ("(\"");
+				else
+					g_string_append (cols, ", \"");
+				g_string_append (cols, g_value_get_string (value));
+				g_string_append_c (cols, '\"');
+				g_string_append_c (cols, ' ');
+			}
+			if (cols) {
+				g_string_append_c (cols, ')');
+				g_string_append (string, cols->str);
+				g_string_free (cols, TRUE);
+			}
+		}
+	}
+
+	if (allok) {
+		value = gda_server_operation_get_value_at (op, "/VIEW_DEF_P/VIEW_DEF");
+		g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
+		g_string_append (string, " AS ");
+		g_string_append (string, g_value_get_string (value));
+	}
+
+	if (allok) {
+		sql = string->str;
+		g_string_free (string, FALSE);
+	}
+	else {
+		sql = NULL;
+		g_string_free (string, TRUE);
+	}
+
+	return sql;
+}
+	
+gchar *
+gda_postgres_render_DROP_VIEW (GdaServerProvider *provider, GdaConnection *cnc, 
+			       GdaServerOperation *op, GError **error)
+{
+	GString *string;
+	const GValue *value;
+	gchar *sql = NULL;
+
+	string = g_string_new ("DROP VIEW");
+
+	value = gda_server_operation_get_value_at (op, "/VIEW_DESC_P/VIEW_IFEXISTS");
+	if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
+		g_string_append (string, " IF EXISTS");
+
+	value = gda_server_operation_get_value_at (op, "/VIEW_DESC_P/VIEW_NAME");
+	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
+	g_string_append_c (string, ' ');
+	g_string_append (string, g_value_get_string (value));
+
+	value = gda_server_operation_get_value_at (op, "/VIEW_DESC_P/REFERENCED_ACTION");
+	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
+	g_string_append_c (string, ' ');
+	g_string_append (string, g_value_get_string (value));
+
+	sql = string->str;
+	g_string_free (string, FALSE);
+
+	return sql;
+}
